@@ -34,7 +34,7 @@ import ConfigParser
 from xml.dom import minidom, Node
 
 #Connect to osso service
-ctx = osso.Context('fSchedule', '0.2', False)
+ctx = osso.Context('fSchedule', '0.1', False)
 
 gtk.gdk.threads_init()
 
@@ -574,7 +574,7 @@ class MainWindow(hildon.StackableWindow):
         dialog.set_title("Preferences")
         btn_options = hildon.PickerButton(gtk.HILDON_SIZE_THUMB_HEIGHT, hildon.BUTTON_ARRANGEMENT_VERTICAL)
         btn_options.set_title("Change Company")
-        btn_options.set_value_alignment(.5, 1)
+        #btn_options.set_value_alignment(.5, 1)
         selector = self.create_cinema_selector()
         btn_options.set_selector(selector)
         btn_options.connect("value-changed", self.value_changed)
@@ -635,7 +635,7 @@ class MainWindow(hildon.StackableWindow):
         self.show_all()
                    
 	def open_url(self, data):
-		#osso_rpc = osso.Rpc(ctx)
+		osso_rpc = osso.Rpc(ctx)
 		osso_rpc.rpc_run("com.nokia.osso_browser","/com/nokia/osso_browser/request", 'com.nokia.osso_browser','load_url',rpc_args=('http://www.forum.nokia.com/',))
 
     def read_config(self):
